@@ -25,22 +25,12 @@
 // a build time HIGHSCORE_DIRECTORY or not
 // #include <config-highscore.h>
 
-namespace {
-auto returnEndLine() {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
-     return endl;
-#else
-     return Qt::endl;
-#endif
-}
-}
-
 namespace KExtHighscore
 {
 
 //-----------------------------------------------------------------------------
 const char ItemContainer::ANONYMOUS[] = "_";
-const char ItemContainer::ANONYMOUS_LABEL[] = I18N_NOOP("anonymous");
+const KLazyLocalizedString ItemContainer::ANONYMOUS_LABEL = kli18n("anonymous");
 
 ItemContainer::ItemContainer()
     : _item(nullptr)
@@ -211,7 +201,7 @@ void ItemArray::exportToText(QTextStream &s) const
                 else s << at(i)->pretty(k-1);
             }
         }
-        s << returnEndLine();
+        s << Qt::endl;
     }
 }
 
@@ -468,7 +458,7 @@ bool PlayerInfos::isNameUsed(const QString &newName) const
     if ( newName==name() ) return false; // own name...
     for (uint i=0; i<nbEntries(); i++)
         if ( newName.toLower()==item(QStringLiteral( "name" ))->read(i).toString().toLower() ) return true;
-    if ( newName==i18n(ItemContainer::ANONYMOUS_LABEL) ) return true;
+    if ( newName==ItemContainer::ANONYMOUS_LABEL.toString() ) return true;
     return false;
 }
 
@@ -593,27 +583,27 @@ QUrl ManagerPrivate::queryUrl(QueryType type, const QString &newName) const
 }
 
 // strings that needs to be translated (coming from the highscores server)
-const char *DUMMY_STRINGS[] = {
-    I18N_NOOP("Undefined error."),
-    I18N_NOOP("Missing argument(s)."),
-    I18N_NOOP("Invalid argument(s)."),
+const KLazyLocalizedString DUMMY_STRINGS[] = {
+    kli18n("Undefined error."),
+    kli18n("Missing argument(s)."),
+    kli18n("Invalid argument(s)."),
 
-    I18N_NOOP("Unable to connect to MySQL server."),
-    I18N_NOOP("Unable to select database."),
-    I18N_NOOP("Error on database query."),
-    I18N_NOOP("Error on database insert."),
+    kli18n("Unable to connect to MySQL server."),
+    kli18n("Unable to select database."),
+    kli18n("Error on database query."),
+    kli18n("Error on database insert."),
 
-    I18N_NOOP("Nickname already registered."),
-    I18N_NOOP("Nickname not registered."),
-    I18N_NOOP("Invalid key."),
-    I18N_NOOP("Invalid submit key."),
+    kli18n("Nickname already registered."),
+    kli18n("Nickname not registered."),
+    kli18n("Invalid key."),
+    kli18n("Invalid submit key."),
 
-    I18N_NOOP("Invalid level."),
-    I18N_NOOP("Invalid score.")
+    kli18n("Invalid level."),
+    kli18n("Invalid score.")
 };
 
-const char *UNABLE_TO_CONTACT =
-    I18N_NOOP("Unable to contact world-wide highscore server");
+const KLazyLocalizedString UNABLE_TO_CONTACT =
+    kli18n("Unable to contact world-wide highscore server");
 
 bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
                                 QDomNamedNodeMap *map)
@@ -623,7 +613,7 @@ bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
     QTemporaryFile tmpFile;
     if ( !tmpFile.open() ) {
         QString details = i18n("Unable to open temporary file.");
-        KMessageBox::detailedSorry(parent, i18n(UNABLE_TO_CONTACT), details);
+        KMessageBox::detailedSorry(parent, UNABLE_TO_CONTACT.toString(), details);
         return false;
     }
 
@@ -632,7 +622,7 @@ bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
     copyJob->exec();
     if( copyJob->error() ) {
         QString details = i18n("Server URL: %1", url.host());
-        KMessageBox::detailedSorry(parent, i18n(UNABLE_TO_CONTACT), details);
+        KMessageBox::detailedSorry(parent, UNABLE_TO_CONTACT.toString(), details);
         return false;
     }
 
@@ -651,6 +641,7 @@ bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
         if ( element.tagName()==QLatin1String( "error" ) ) {
             QDomAttr attr = element.attributes().namedItem(QStringLiteral( "label" )).toAttr();
             if ( !attr.isNull() ) {
+                // see DUMMY_STRINGS
                 QString msg = i18n(attr.value().toLatin1());
                 QString caption = i18n("Message from world-wide highscores "
                                        "server");
@@ -862,16 +853,16 @@ void ManagerPrivate::exportHighscores(QTextStream &s)
     for (uint i=0; i<_nbGameTypes; i++) {
         setGameType(i);
         if ( _nbGameTypes>1 ) {
-            if ( i!=0 ) s << returnEndLine();
-            s << "--------------------------------" << returnEndLine();
+            if ( i!=0 ) s << Qt::endl;
+            s << "--------------------------------" << Qt::endl;
             s << "Game type: "
-              << manager.gameTypeLabel(_gameType, Manager::I18N) << returnEndLine();
-            s << returnEndLine();
+              << manager.gameTypeLabel(_gameType, Manager::I18N) << Qt::endl;
+            s << Qt::endl;
         }
-        s << "Players list:" << returnEndLine();
+        s << "Players list:" << Qt::endl;
         _playerInfos->exportToText(s);
-        s << returnEndLine();
-        s << "Highscores list:" << returnEndLine();
+        s << Qt::endl;
+        s << "Highscores list:" << Qt::endl;
         _scoreInfos->exportToText(s);
     }
 
